@@ -481,16 +481,11 @@ class IceServer(TypedDict):
     credential: Optional[str]
 
 
-class FrameResolution(TypedDict):
-    width: int
-    height: int
-
-
 class FrameMetadata(TypedDict):
-    index: int
     format: str
     frameSize: int
-    resolution: FrameResolution
+    width: int
+    height: int
 
 
 class Frame(TypedDict):
